==> kdepim-4.8.5-arm-1.tgz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libakregatorinterfaces.so )
( cd usr/lib ; ln -sf libakregatorinterfaces.so.4 libakregatorinterfaces.so )
( cd usr/lib ; rm -rf libmessagecore.so )
( cd usr/lib ; ln -sf libmessagecore.so.4 libmessagecore.so )
( cd usr/lib ; rm -rf libksieveui.so )
( cd usr/lib ; ln -sf libksieveui.so.4 libksieveui.so )
( cd usr/lib ; rm -rf libakregatorprivate.so.4 )
( cd usr/lib ; ln -sf libakregatorprivate.so.4.8.0 libakregatorprivate.so.4 )
( cd usr/lib ; rm -rf libkdepimdbusinterfaces.so )
( cd usr/lib ; ln -sf libkdepimdbusinterfaces.so.4 libkdepimdbusinterfaces.so )
( cd usr/lib ; rm -rf libmessagecore.so.4 )
( cd usr/lib ; ln -sf libmessagecore.so.4.8.0 libmessagecore.so.4 )
( cd usr/lib ; rm -rf libincidenceeditorsngmobile.so )
( cd usr/lib ; ln -sf libincidenceeditorsngmobile.so.4 libincidenceeditorsngmobile.so )
( cd usr/lib ; rm -rf libkleopatraclientgui.so.0 )
( cd usr/lib ; ln -sf libkleopatraclientgui.so.0.3.0 libkleopatraclientgui.so.0 )
( cd usr/lib ; rm -rf libkorganizerprivate.so.4 )
( cd usr/lib ; ln -sf libkorganizerprivate.so.4.8.0 libkorganizerprivate.so.4 )
( cd usr/lib ; rm -rf libkpgp.so.4 )
( cd usr/lib ; ln -sf libkpgp.so.4.8.0 libkpgp.so.4 )
( cd usr/lib ; rm -rf libkcal_resourceremote.so )
( cd usr/lib ; ln -sf libkcal_resourceremote.so.4 libkcal_resourceremote.so )
( cd usr/lib ; rm -rf libmessageviewer.so.4 )
( cd usr/lib ; ln -sf libmessageviewer.so.4.8.0 libmessageviewer.so.4 )
( cd usr/lib ; rm -rf libkdepimmobileui.so )
( cd usr/lib ; ln -sf libkdepimmobileui.so.4 libkdepimmobileui.so )
( cd usr/lib ; rm -rf libincidenceeditorsng.so )
( cd usr/lib ; ln -sf libincidenceeditorsng.so.4 libincidenceeditorsng.so )
( cd usr/lib ; rm -rf libakonadi_next.so.4 )
( cd usr/lib ; ln -sf libakonadi_next.so.4.8.0 libakonadi_next.so.4 )
( cd usr/lib ; rm -rf libmailcommon.so.4 )
( cd usr/lib ; ln -sf libmailcommon.so.4.8.0 libmailcommon.so.4 )
( cd usr/lib ; rm -rf libknodecommon.so )
( cd usr/lib ; ln -sf libknodecommon.so.4 libknodecommon.so )
( cd usr/lib ; rm -rf libmailcommon.so )
( cd usr/lib ; ln -sf libmailcommon.so.4 libmailcommon.so )
( cd usr/lib ; rm -rf libkdepim.so.4 )
( cd usr/lib ; ln -sf libkdepim.so.4.8.0 libkdepim.so.4 )
( cd usr/lib ; rm -rf libkaddressbookprivate.so.4 )
( cd usr/lib ; ln -sf libkaddressbookprivate.so.4.8.0 libkaddressbookprivate.so.4 )
( cd usr/lib ; rm -rf libcalendarsupport.so )
( cd usr/lib ; ln -sf libcalendarsupport.so.4 libcalendarsupport.so )
( cd usr/lib ; rm -rf libkorganizer_core.so.4 )
( cd usr/lib ; ln -sf libkorganizer_core.so.4.8.0 libkorganizer_core.so.4 )
( cd usr/lib ; rm -rf libtemplateparser.so.4 )
( cd usr/lib ; ln -sf libtemplateparser.so.4.8.0 libtemplateparser.so.4 )
( cd usr/lib ; rm -rf libkdepim.so )
( cd usr/lib ; ln -sf libkdepim.so.4 libkdepim.so )
( cd usr/lib ; rm -rf libkleopatraclientcore.so.0 )
( cd usr/lib ; ln -sf libkleopatraclientcore.so.0.3.0 libkleopatraclientcore.so.0 )
( cd usr/lib ; rm -rf libakregatorinterfaces.so.4 )
( cd usr/lib ; ln -sf libakregatorinterfaces.so.4.8.0 libakregatorinterfaces.so.4 )
( cd usr/lib ; rm -rf libcalendarsupport.so.4 )
( cd usr/lib ; ln -sf libcalendarsupport.so.4.8.0 libcalendarsupport.so.4 )
( cd usr/lib ; rm -rf libkcal_resourceremote.so.4 )
( cd usr/lib ; ln -sf libkcal_resourceremote.so.4.8.0 libkcal_resourceremote.so.4 )
( cd usr/lib ; rm -rf libkmanagesieve.so.4 )
( cd usr/lib ; ln -sf libkmanagesieve.so.4.8.0 libkmanagesieve.so.4 )
( cd usr/lib ; rm -rf libkorganizer_interfaces.so )
( cd usr/lib ; ln -sf libkorganizer_interfaces.so.4 libkorganizer_interfaces.so )
( cd usr/lib ; rm -rf libmessagecomposer.so.4 )
( cd usr/lib ; ln -sf libmessagecomposer.so.4.8.0 libmessagecomposer.so.4 )
( cd usr/lib ; rm -rf libkleo.so.4 )
( cd usr/lib ; ln -sf libkleo.so.4.8.0 libkleo.so.4 )
( cd usr/lib ; rm -rf libmessagecomposer.so )
( cd usr/lib ; ln -sf libmessagecomposer.so.4 libmessagecomposer.so )
( cd usr/lib ; rm -rf libakonadi_next.so )
( cd usr/lib ; ln -sf libakonadi_next.so.4 libakonadi_next.so )
( cd usr/lib ; rm -rf libkleopatraclientgui.so )
( cd usr/lib ; ln -sf libkleopatraclientgui.so.0 libkleopatraclientgui.so )
( cd usr/lib ; rm -rf libkdepimmobileui.so.4 )
( cd usr/lib ; ln -sf libkdepimmobileui.so.4.8.0 libkdepimmobileui.so.4 )
( cd usr/lib ; rm -rf libmessageviewer.so )
( cd usr/lib ; ln -sf libmessageviewer.so.4 libmessageviewer.so )
( cd usr/lib ; rm -rf libksieve.so.4 )
( cd usr/lib ; ln -sf libksieve.so.4.8.0 libksieve.so.4 )
( cd usr/lib ; rm -rf libkorganizer_interfaces.so.4 )
( cd usr/lib ; ln -sf libkorganizer_interfaces.so.4.8.0 libkorganizer_interfaces.so.4 )
( cd usr/lib ; rm -rf libkpgp.so )
( cd usr/lib ; ln -sf libkpgp.so.4 libkpgp.so )
( cd usr/lib ; rm -rf libkcal_resourceblog.so.4 )
( cd usr/lib ; ln -sf libkcal_resourceblog.so.4.8.0 libkcal_resourceblog.so.4 )
( cd usr/lib ; rm -rf libeventviews.so.4 )
( cd usr/lib ; ln -sf libeventviews.so.4.8.0 libeventviews.so.4 )
( cd usr/lib ; rm -rf libkdepimdbusinterfaces.so.4 )
( cd usr/lib ; ln -sf libkdepimdbusinterfaces.so.4.8.0 libkdepimdbusinterfaces.so.4 )
( cd usr/lib ; rm -rf libtemplateparser.so )
( cd usr/lib ; ln -sf libtemplateparser.so.4 libtemplateparser.so )
( cd usr/lib ; rm -rf libeventviews.so )
( cd usr/lib ; ln -sf libeventviews.so.4 libeventviews.so )
( cd usr/lib ; rm -rf libkcal_resourceblog.so )
( cd usr/lib ; ln -sf libkcal_resourceblog.so.4 libkcal_resourceblog.so )
( cd usr/lib ; rm -rf libkleo.so )
( cd usr/lib ; ln -sf libkleo.so.4 libkleo.so )
( cd usr/lib ; rm -rf libksieveui.so.4 )
( cd usr/lib ; ln -sf libksieveui.so.4.8.0 libksieveui.so.4 )
( cd usr/lib ; rm -rf libkorganizer_core.so )
( cd usr/lib ; ln -sf libkorganizer_core.so.4 libkorganizer_core.so )
( cd usr/lib ; rm -rf libmessagelist.so.4 )
( cd usr/lib ; ln -sf libmessagelist.so.4.8.0 libmessagelist.so.4 )
( cd usr/lib ; rm -rf libincidenceeditorsng.so.4 )
( cd usr/lib ; ln -sf libincidenceeditorsng.so.4.8.0 libincidenceeditorsng.so.4 )
( cd usr/lib ; rm -rf libincidenceeditorsngmobile.so.4 )
( cd usr/lib ; ln -sf libincidenceeditorsngmobile.so.4.8.0 libincidenceeditorsngmobile.so.4 )
( cd usr/lib ; rm -rf libkontactprivate.so.4 )
( cd usr/lib ; ln -sf libkontactprivate.so.4.8.0 libkontactprivate.so.4 )
( cd usr/lib ; rm -rf libkmanagesieve.so )
( cd usr/lib ; ln -sf libkmanagesieve.so.4 libkmanagesieve.so )
( cd usr/lib ; rm -rf libksieve.so )
( cd usr/lib ; ln -sf libksieve.so.4 libksieve.so )
( cd usr/lib ; rm -rf libknodecommon.so.4 )
( cd usr/lib ; ln -sf libknodecommon.so.4.8.0 libknodecommon.so.4 )
( cd usr/lib ; rm -rf libkdgantt2.so )
( cd usr/lib ; ln -sf libkdgantt2.so.0 libkdgantt2.so )
( cd usr/lib ; rm -rf libkleopatraclientcore.so )
( cd usr/lib ; ln -sf libkleopatraclientcore.so.0 libkleopatraclientcore.so )
( cd usr/lib ; rm -rf libmessagelist.so )
( cd usr/lib ; ln -sf libmessagelist.so.4 libmessagelist.so )
( cd usr/lib ; rm -rf libkdgantt2.so.0 )
( cd usr/lib ; ln -sf libkdgantt2.so.0.1.0 libkdgantt2.so.0 )
( cd usr/lib ; rm -rf libkmailprivate.so.4 )
( cd usr/lib ; ln -sf libkmailprivate.so.4.8.0 libkmailprivate.so.4 )
( cd usr/doc/HTML/en/kontact ; rm -rf common )
( cd usr/doc/HTML/en/kontact ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kontact-admin ; rm -rf common )
( cd usr/doc/HTML/en/kontact-admin ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/knode ; rm -rf common )
( cd usr/doc/HTML/en/knode ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/akregator ; rm -rf common )
( cd usr/doc/HTML/en/akregator ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kwatchgnupg ; rm -rf common )
( cd usr/doc/HTML/en/kwatchgnupg ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kjots ; rm -rf common )
( cd usr/doc/HTML/en/kjots ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/news ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/news ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/korganizer ; rm -rf common )
( cd usr/doc/HTML/en/korganizer ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kabcclient ; rm -rf common )
( cd usr/doc/HTML/en/kabcclient ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/ktimetracker ; rm -rf common )
( cd usr/doc/HTML/en/ktimetracker ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kleopatra ; rm -rf common )
( cd usr/doc/HTML/en/kleopatra ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kalarm ; rm -rf common )
( cd usr/doc/HTML/en/kalarm ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/blogilo ; rm -rf common )
( cd usr/doc/HTML/en/blogilo ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/konsolekalendar ; rm -rf common )
( cd usr/doc/HTML/en/konsolekalendar ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kmail ; rm -rf common )
( cd usr/doc/HTML/en/kmail ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/knotes ; rm -rf common )
( cd usr/doc/HTML/en/knotes ; ln -sf /usr/share/doc/HTML/en/common common )

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

==> kdepim-4.10.5-arm-1.tgz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libkleopatraclientgui.so.0 )
( cd usr/lib ; ln -sf libkleopatraclientgui.so.0.3.0 libkleopatraclientgui.so.0 )
( cd usr/lib ; rm -rf libknodecommon.so.4 )
( cd usr/lib ; ln -sf libknodecommon.so.4.10.5 libknodecommon.so.4 )
( cd usr/lib ; rm -rf libmailimporter.so )
( cd usr/lib ; ln -sf libmailimporter.so.4 libmailimporter.so )
( cd usr/lib ; rm -rf libmessagecore.so )
( cd usr/lib ; ln -sf libmessagecore.so.4 libmessagecore.so )
( cd usr/lib ; rm -rf libcalendarsupport.so.4 )
( cd usr/lib ; ln -sf libcalendarsupport.so.4.10.5 libcalendarsupport.so.4 )
( cd usr/lib ; rm -rf libmessagecomposer.so.4 )
( cd usr/lib ; ln -sf libmessagecomposer.so.4.10.5 libmessagecomposer.so.4 )
( cd usr/lib ; rm -rf libmessagecomposer.so )
( cd usr/lib ; ln -sf libmessagecomposer.so.4 libmessagecomposer.so )
( cd usr/lib ; rm -rf libkmanagesieve.so.4 )
( cd usr/lib ; ln -sf libkmanagesieve.so.4.10.5 libkmanagesieve.so.4 )
( cd usr/lib ; rm -rf libkleo.so )
( cd usr/lib ; ln -sf libkleo.so.4 libkleo.so )
( cd usr/lib ; rm -rf libakregatorinterfaces.so )
( cd usr/lib ; ln -sf libakregatorinterfaces.so.4 libakregatorinterfaces.so )
( cd usr/lib ; rm -rf libksieve.so.4 )
( cd usr/lib ; ln -sf libksieve.so.4.10.5 libksieve.so.4 )
( cd usr/lib ; rm -rf libkmanagesieve.so )
( cd usr/lib ; ln -sf libkmanagesieve.so.4 libkmanagesieve.so )
( cd usr/lib ; rm -rf libmessageviewer.so.4 )
( cd usr/lib ; ln -sf libmessageviewer.so.4.10.5 libmessageviewer.so.4 )
( cd usr/lib ; rm -rf libpimcommon.so.4 )
( cd usr/lib ; ln -sf libpimcommon.so.4.10.5 libpimcommon.so.4 )
( cd usr/lib ; rm -rf libkleopatraclientgui.so )
( cd usr/lib ; ln -sf libkleopatraclientgui.so.0 libkleopatraclientgui.so )
( cd usr/lib ; rm -rf libakregatorinterfaces.so.4 )
( cd usr/lib ; ln -sf libakregatorinterfaces.so.4.10.5 libakregatorinterfaces.so.4 )
( cd usr/lib ; rm -rf libcalendarsupport.so )
( cd usr/lib ; ln -sf libcalendarsupport.so.4 libcalendarsupport.so )
( cd usr/lib ; rm -rf libtemplateparser.so )
( cd usr/lib ; ln -sf libtemplateparser.so.4 libtemplateparser.so )
( cd usr/lib ; rm -rf libeventviews.so )
( cd usr/lib ; ln -sf libeventviews.so.4 libeventviews.so )
( cd usr/lib ; rm -rf libksieveui.so.4 )
( cd usr/lib ; ln -sf libksieveui.so.4.10.5 libksieveui.so.4 )
( cd usr/lib ; rm -rf libpimcommon.so )
( cd usr/lib ; ln -sf libpimcommon.so.4 libpimcommon.so )
( cd usr/lib ; rm -rf libkdepimdbusinterfaces.so.4 )
( cd usr/lib ; ln -sf libkdepimdbusinterfaces.so.4.10.5 libkdepimdbusinterfaces.so.4 )
( cd usr/lib ; rm -rf libkcal_resourceremote.so )
( cd usr/lib ; ln -sf libkcal_resourceremote.so.4 libkcal_resourceremote.so )
( cd usr/lib ; rm -rf libmailimporter.so.4 )
( cd usr/lib ; ln -sf libmailimporter.so.4.10.5 libmailimporter.so.4 )
( cd usr/lib ; rm -rf libmessagelist.so.4 )
( cd usr/lib ; ln -sf libmessagelist.so.4.10.5 libmessagelist.so.4 )
( cd usr/lib ; rm -rf libmailcommon.so )
( cd usr/lib ; ln -sf libmailcommon.so.4 libmailcommon.so )
( cd usr/lib ; rm -rf libkdepimdbusinterfaces.so )
( cd usr/lib ; ln -sf libkdepimdbusinterfaces.so.4 libkdepimdbusinterfaces.so )
( cd usr/lib ; rm -rf libkdepim.so )
( cd usr/lib ; ln -sf libkdepim.so.4 libkdepim.so )
( cd usr/lib ; rm -rf libknodecommon.so )
( cd usr/lib ; ln -sf libknodecommon.so.4 libknodecommon.so )
( cd usr/lib ; rm -rf libkdgantt2.so )
( cd usr/lib ; ln -sf libkdgantt2.so.0 libkdgantt2.so )
( cd usr/lib ; rm -rf libmessagecore.so.4 )
( cd usr/lib ; ln -sf libmessagecore.so.4.10.5 libmessagecore.so.4 )
( cd usr/lib ; rm -rf libksieveui.so )
( cd usr/lib ; ln -sf libksieveui.so.4 libksieveui.so )
( cd usr/lib ; rm -rf libakonadi_next.so.4 )
( cd usr/lib ; ln -sf libakonadi_next.so.4.10.5 libakonadi_next.so.4 )
( cd usr/lib ; rm -rf libkorganizer_interfaces.so.4 )
( cd usr/lib ; ln -sf libkorganizer_interfaces.so.4.10.5 libkorganizer_interfaces.so.4 )
( cd usr/lib ; rm -rf libakregatorprivate.so.4 )
( cd usr/lib ; ln -sf libakregatorprivate.so.4.10.5 libakregatorprivate.so.4 )
( cd usr/lib ; rm -rf libtemplateparser.so.4 )
( cd usr/lib ; ln -sf libtemplateparser.so.4.10.5 libtemplateparser.so.4 )
( cd usr/lib ; rm -rf libkontactprivate.so.4 )
( cd usr/lib ; ln -sf libkontactprivate.so.4.10.5 libkontactprivate.so.4 )
( cd usr/lib ; rm -rf libincidenceeditorsng.so.4 )
( cd usr/lib ; ln -sf libincidenceeditorsng.so.4.10.5 libincidenceeditorsng.so.4 )
( cd usr/lib ; rm -rf libkmailprivate.so.4 )
( cd usr/lib ; ln -sf libkmailprivate.so.4.10.5 libkmailprivate.so.4 )
( cd usr/lib ; rm -rf libincidenceeditorsng.so )
( cd usr/lib ; ln -sf libincidenceeditorsng.so.4 libincidenceeditorsng.so )
( cd usr/lib ; rm -rf libkcal_resourceremote.so.4 )
( cd usr/lib ; ln -sf libkcal_resourceremote.so.4.10.5 libkcal_resourceremote.so.4 )
( cd usr/lib ; rm -rf libkleopatraclientcore.so.0 )
( cd usr/lib ; ln -sf libkleopatraclientcore.so.0.3.0 libkleopatraclientcore.so.0 )
( cd usr/lib ; rm -rf libksieve.so )
( cd usr/lib ; ln -sf libksieve.so.4 libksieve.so )
( cd usr/lib ; rm -rf libkleo.so.4 )
( cd usr/lib ; ln -sf libkleo.so.4.10.5 libkleo.so.4 )
( cd usr/lib ; rm -rf libkleopatraclientcore.so )
( cd usr/lib ; ln -sf libkleopatraclientcore.so.0 libkleopatraclientcore.so )
( cd usr/lib ; rm -rf libmessagelist.so )
( cd usr/lib ; ln -sf libmessagelist.so.4 libmessagelist.so )
( cd usr/lib ; rm -rf libkpgp.so.4 )
( cd usr/lib ; ln -sf libkpgp.so.4.10.5 libkpgp.so.4 )
( cd usr/lib ; rm -rf libkorganizer_core.so.4 )
( cd usr/lib ; ln -sf libkorganizer_core.so.4.10.5 libkorganizer_core.so.4 )
( cd usr/lib ; rm -rf libkcal_resourceblog.so )
( cd usr/lib ; ln -sf libkcal_resourceblog.so.4 libkcal_resourceblog.so )
( cd usr/lib ; rm -rf libkorganizer_interfaces.so )
( cd usr/lib ; ln -sf libkorganizer_interfaces.so.4 libkorganizer_interfaces.so )
( cd usr/lib ; rm -rf libakonadi_next.so )
( cd usr/lib ; ln -sf libakonadi_next.so.4 libakonadi_next.so )
( cd usr/lib ; rm -rf libkdepimmobileui.so.4 )
( cd usr/lib ; ln -sf libkdepimmobileui.so.4.10.5 libkdepimmobileui.so.4 )
( cd usr/lib ; rm -rf libkdepim.so.4 )
( cd usr/lib ; ln -sf libkdepim.so.4.10.5 libkdepim.so.4 )
( cd usr/lib ; rm -rf libkdgantt2.so.0 )
( cd usr/lib ; ln -sf libkdgantt2.so.0.1.0 libkdgantt2.so.0 )
( cd usr/lib ; rm -rf libkdepimmobileui.so )
( cd usr/lib ; ln -sf libkdepimmobileui.so.4 libkdepimmobileui.so )
( cd usr/lib ; rm -rf libincidenceeditorsngmobile.so.4 )
( cd usr/lib ; ln -sf libincidenceeditorsngmobile.so.4.10.5 libincidenceeditorsngmobile.so.4 )
( cd usr/lib ; rm -rf libkorganizerprivate.so.4 )
( cd usr/lib ; ln -sf libkorganizerprivate.so.4.10.5 libkorganizerprivate.so.4 )
( cd usr/lib ; rm -rf libmailcommon.so.4 )
( cd usr/lib ; ln -sf libmailcommon.so.4.10.5 libmailcommon.so.4 )
( cd usr/lib ; rm -rf libkorganizer_core.so )
( cd usr/lib ; ln -sf libkorganizer_core.so.4 libkorganizer_core.so )
( cd usr/lib ; rm -rf libmessageviewer.so )
( cd usr/lib ; ln -sf libmessageviewer.so.4 libmessageviewer.so )
( cd usr/lib ; rm -rf libincidenceeditorsngmobile.so )
( cd usr/lib ; ln -sf libincidenceeditorsngmobile.so.4 libincidenceeditorsngmobile.so )
( cd usr/lib ; rm -rf libkpgp.so )
( cd usr/lib ; ln -sf libkpgp.so.4 libkpgp.so )
( cd usr/lib ; rm -rf libkcal_resourceblog.so.4 )
( cd usr/lib ; ln -sf libkcal_resourceblog.so.4.10.5 libkcal_resourceblog.so.4 )
( cd usr/lib ; rm -rf libkaddressbookprivate.so.4 )
( cd usr/lib ; ln -sf libkaddressbookprivate.so.4.10.5 libkaddressbookprivate.so.4 )
( cd usr/lib ; rm -rf libeventviews.so.4 )
( cd usr/lib ; ln -sf libeventviews.so.4.10.5 libeventviews.so.4 )
( cd usr/doc/HTML/en/kioslave/news ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/news ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/ktnef ; rm -rf common )
( cd usr/doc/HTML/en/ktnef ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kontact-admin ; rm -rf common )
( cd usr/doc/HTML/en/kontact-admin ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kalarm ; rm -rf common )
( cd usr/doc/HTML/en/kalarm ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/korganizer ; rm -rf common )
( cd usr/doc/HTML/en/korganizer ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/blogilo ; rm -rf common )
( cd usr/doc/HTML/en/blogilo ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kjots ; rm -rf common )
( cd usr/doc/HTML/en/kjots ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/knode ; rm -rf common )
( cd usr/doc/HTML/en/knode ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/konsolekalendar ; rm -rf common )
( cd usr/doc/HTML/en/konsolekalendar ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kmail ; rm -rf common )
( cd usr/doc/HTML/en/kmail ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/akregator ; rm -rf common )
( cd usr/doc/HTML/en/akregator ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kontact ; rm -rf common )
( cd usr/doc/HTML/en/kontact ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kabcclient ; rm -rf common )
( cd usr/doc/HTML/en/kabcclient ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/knotes ; rm -rf common )
( cd usr/doc/HTML/en/knotes ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kleopatra ; rm -rf common )
( cd usr/doc/HTML/en/kleopatra ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/ktimetracker ; rm -rf common )
( cd usr/doc/HTML/en/ktimetracker ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kwatchgnupg ; rm -rf common )
( cd usr/doc/HTML/en/kwatchgnupg ; ln -sf /usr/share/doc/HTML/en/common common )
